@@ -10,8 +10,6 @@ pub mod ansible_extra_vars;
 pub use self::ansible_extra_vars::AnsibleExtraVars;
 pub mod ansible_extra_vars_request;
 pub use self::ansible_extra_vars_request::AnsibleExtraVarsRequest;
-pub mod ansible_state_enum;
-pub use self::ansible_state_enum::AnsibleStateEnum;
 pub mod artifact_types_enum;
 pub use self::artifact_types_enum::ArtifactTypesEnum;
 pub mod ca_certs;
@@ -32,8 +30,6 @@ pub mod cloudiot_device;
 pub use self::cloudiot_device::CloudiotDevice;
 pub mod cloudiot_device_request;
 pub use self::cloudiot_device_request::CloudiotDeviceRequest;
-pub mod command_enum;
-pub use self::command_enum::CommandEnum;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
 pub mod device;
@@ -50,6 +46,8 @@ pub mod device_request;
 pub use self::device_request::DeviceRequest;
 pub mod device_state;
 pub use self::device_state::DeviceState;
+pub mod device_state_command_enum;
+pub use self::device_state_command_enum::DeviceStateCommandEnum;
 pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
@@ -248,10 +246,14 @@ pub mod remote_command_event_request;
 pub use self::remote_command_event_request::RemoteCommandEventRequest;
 pub mod remote_control_command;
 pub use self::remote_control_command::RemoteControlCommand;
+pub mod remote_control_command_command_enum;
+pub use self::remote_control_command_command_enum::RemoteControlCommandCommandEnum;
 pub mod remote_control_command_request;
 pub use self::remote_control_command_request::RemoteControlCommandRequest;
 pub mod software_enum;
 pub use self::software_enum::SoftwareEnum;
+pub mod status_enum;
+pub use self::status_enum::StatusEnum;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_event_type_enum;
